<?php
/**
 * Product Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'pet_business_pro_product_section', array(
	'title'             => esc_html__( 'Product','pet-business-pro' ),
	'description'       => esc_html__( 'Product Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Product content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[product_section_enable]', array(
	'default'			=> 	$options['product_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[product_section_enable]', array(
	'label'             => esc_html__( 'Product Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_product_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// product title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[product_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_product_section',
	'active_callback' 	=> 'pet_business_pro_is_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[product_title]', array(
		'selector'            => '#shop-products h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_product_title_partial',
    ) );
}

// product sub title
$wp_customize->add_setting( 'pet_business_pro_theme_options[product_sub_title]', array(
	'default'          	=> $options['product_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[product_sub_title]', array(
	'label'             => esc_html__( 'Sub title', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_product_section',
	'active_callback'	=> 'pet_business_pro_is_product_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[product_sub_title]', array(
		'selector'            => '#shop-products .section-subtitle',
		'settings'            => 'pet_business_pro_theme_options[product_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_product_sub_title_partial',
    ) );
}

// product number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[product_count]', array(
	'default'          	=> $options['product_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_product_section',
	'active_callback'   => 'pet_business_pro_is_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Product content type control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[product_content_type]', array(
	'default'          	=> $options['product_content_type'],
	'sanitize_callback' => 'pet_business_pro_sanitize_select',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pet_business_pro_is_product_section_enable',
	'choices'			=> pet_business_pro_product_section_options(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pet_business_pro_theme_options[product_content_category]', array(
	'sanitize_callback' => 'pet_business_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Taxonomies_Control( $wp_customize,'pet_business_pro_theme_options[product_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pet-business-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_product_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pet_business_pro_is_product_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['product_count']; $i++ ) :

	// product pages drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_product_section',
		'choices'			=> pet_business_pro_page_choices(),
		'active_callback'	=> 'pet_business_pro_is_product_section_content_page_enable',
	) ) );

	if ( class_exists( 'WooCommerce' ) ) {
		// product pages drop down chooser control and setting
		$wp_customize->add_setting( 'pet_business_pro_theme_options[product_content_woo_product_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[product_content_woo_product_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Product %d', 'pet-business-pro' ), $i ),
			'section'           => 'pet_business_pro_product_section',
			'choices'			=> pet_business_pro_product_choices(),
			'active_callback'	=> 'pet_business_pro_is_product_section_content_product_enable',
		) ) );
	}

	// product posts drop down chooser control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[product_content_post_' . $i . ']', array(
		'sanitize_callback' => 'pet_business_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Dropdown_Chooser( $wp_customize, 'pet_business_pro_theme_options[product_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_product_section',
		'choices'			=> pet_business_pro_post_choices(),
		'active_callback'	=> 'pet_business_pro_is_product_section_content_post_enable',
	) ) );

	// product custom date
	$wp_customize->add_setting( 'pet_business_pro_theme_options[product_custom_meta_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[product_custom_meta_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Meta %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_product_section',
		'active_callback'	=> 'pet_business_pro_is_product_section_content_page_enable',
	) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[product_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[product_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_product_section',
		'active_callback'	=> 'pet_business_pro_is_product_section_content_page_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;

